@@ -75,6 +75,13 @@ SUPPORTED_LANGUAGES = [
     "pa",
     "fa",
     "ar",
+    "acm",
+    "afb",
+    "akw",
+    "ama",
+    "apc",
+    "apd",
+    "arz",
     "el",
     "da",
     "en",
