@@ -38,6 +38,13 @@ class DataConverter:
     def count(dataset):
         return len(dataset)
 
+    @staticmethod
+    def get_converted_file_name(filename: Text, prefix: Text) -> Text:
+        prefixed_file_name = filename
+        if prefix:
+            prefixed_file_name = f"{prefix}-{filename}"
+        return prefixed_file_name
+
     @staticmethod
     def save_converted_data(
         output_directory: Path,
@@ -45,20 +52,33 @@ class DataConverter:
         regex_data: Optional[List[Dict[Text, Any]]] = None,
         synonym_data: Optional[List[Dict[Text, Any]]] = None,
         nlu_data: Optional[List[Dict[Text, Any]]] = None,
+        dataset_id: Optional[Text] = None,
     ):
         output_directory.mkdir(parents=True, exist_ok=True)
 
         if lookup_data is not None:
-            with open(output_directory / DataConverter.LOOKUP_FILE, "w") as f:
+            lookup_file_name = DataConverter.get_converted_file_name(
+                DataConverter.LOOKUP_FILE, dataset_id
+            )
+            with open(output_directory / lookup_file_name, "w") as f:
                 json.dump(lookup_data, f, indent=4, ensure_ascii=False)
         if regex_data is not None:
-            with open(output_directory / DataConverter.REGEX_FILE, "w") as f:
+            regex_file_name = DataConverter.get_converted_file_name(
+                DataConverter.REGEX_FILE, dataset_id
+            )
+            with open(output_directory / regex_file_name, "w") as f:
                 json.dump(regex_data, f, indent=4, ensure_ascii=False)
         if synonym_data is not None:
-            with open(output_directory / DataConverter.SYNONYM_FILE, "w") as f:
+            synonym_file_name = DataConverter.get_converted_file_name(
+                DataConverter.SYNONYM_FILE, dataset_id
+            )
+            with open(output_directory / synonym_file_name, "w") as f:
                 json.dump(synonym_data, f, indent=4, ensure_ascii=False)
         if nlu_data is not None:
-            with open(output_directory / DataConverter.NLU_FILE, "w") as f:
+            nlu_file_name = DataConverter.get_converted_file_name(
+                DataConverter.NLU_FILE, dataset_id
+            )
+            with open(output_directory / nlu_file_name, "w") as f:
                 json.dump(nlu_data, f, indent=4, ensure_ascii=False)
 
     def set_data_type(self, dataset_type: DatasetType = "train"):
