@@ -1,6 +1,6 @@
 from dataclasses import dataclass
 from pathlib import Path
-from typing import Dict, List, Text
+from typing import Any, Dict, List, Text
 
 import datasets
 from datasets import load_dataset, load_dataset_builder
@@ -30,6 +30,19 @@ class HuggingfaceNerConverter:
             ner_dict[index] = entity
         return ner_dict
 
+    def __get_label_key(self, features: Dict[Text, Any], tag_pattern: Text) -> Text:
+        label_key = None
+        for key in features.keys():
+            if tag_pattern in key:
+                label_key = key
+                break
+        if label_key is None:
+            raise ValueError(
+                f"Dataset does not contain '{tag_pattern}' or '{tag_pattern}s' as features. "
+                "Please use a dataset which is formatted properly on Huggingface."
+            )
+        return label_key
+
     def load_huggingface_dataset(
         self,
         dataset_name: Text,
@@ -39,11 +52,11 @@ class HuggingfaceNerConverter:
     ) -> HuggingfaceDatasetCollection:
         hf_dataset = []
         for subset in subsets:
-            subset_ner_tags = (
-                load_dataset_builder(dataset_name, subset)
-                .info.features["ner_tags"]
-                .feature.names
+            loaded_dataset = load_dataset_builder(dataset_name, subset)
+            ner_label_key = self.__get_label_key(
+                loaded_dataset.info.features, "ner_tag"
             )
+            subset_ner_tags = loaded_dataset.info.features[ner_label_key].feature.names
             dataset = load_dataset(dataset_name, subset)
             if num_train_examples == -1:
                 train_dataset = dataset[TRAIN]
@@ -91,9 +104,11 @@ class HuggingfaceNerConverter:
             ner_dict = subset_dataset.ner_dict
             train_dataset = subset_dataset.train_dataset
             test_dataset = subset_dataset.test_dataset
+            token_label_name = self.__get_label_key(train_dataset.to_dict(), "token")
+            tags_label_name = self.__get_label_key(train_dataset.to_dict(), "ner_tag")
 
-            train_tokens_list = train_dataset["tokens"]
-            train_ner_tags_list = train_dataset["ner_tags"]
+            train_tokens_list = train_dataset[token_label_name]
+            train_ner_tags_list = train_dataset[tags_label_name]
 
             for tokens, ner_tags in zip(train_tokens_list, train_ner_tags_list):
                 text = self.__convert_tokens_and_ner_tags_to_text(
@@ -102,8 +117,8 @@ class HuggingfaceNerConverter:
                 train_list.append(text)
 
             if test_dataset is not None:
-                test_tokens_list = test_dataset["tokens"]
-                test_ner_tags_list = test_dataset["ner_tags"]
+                test_tokens_list = test_dataset[token_label_name]
+                test_ner_tags_list = test_dataset[tags_label_name]
                 for tokens, ner_tags in zip(test_tokens_list, test_ner_tags_list):
                     text = self.__convert_tokens_and_ner_tags_to_text(
                         tokens, ner_tags, ner_dict
